@@ -20,6 +20,7 @@ from tensorflow_datasets.audio.commonvoice import CommonVoice
 from tensorflow_datasets.audio.commonvoice import CommonVoiceConfig
 from tensorflow_datasets.audio.crema_d import CremaD
 from tensorflow_datasets.audio.dementiabank import Dementiabank
+from tensorflow_datasets.audio.fuss import Fuss
 from tensorflow_datasets.audio.groove import Groove
 from tensorflow_datasets.audio.librispeech import Librispeech
 from tensorflow_datasets.audio.librispeech import LibrispeechConfig
@@ -29,4 +30,6 @@ from tensorflow_datasets.audio.nsynth import Nsynth
 from tensorflow_datasets.audio.savee import Savee
 from tensorflow_datasets.audio.speech_commands import SpeechCommands
 from tensorflow_datasets.audio.tedlium import Tedlium
+from tensorflow_datasets.audio.vctk import Vctk
 from tensorflow_datasets.audio.voxceleb import Voxceleb
+from tensorflow_datasets.audio.voxforge import Voxforge
