@@ -36,29 +36,26 @@ from __future__ import division
 from __future__ import print_function
 
 import abc
-import collections
 import json
 import os
 import posixpath
 import tempfile
 
 from absl import logging
-import numpy as np
 import six
 import tensorflow.compat.v2 as tf
 
 from tensorflow_datasets.core import api_utils
-from tensorflow_datasets.core import dataset_utils
 from tensorflow_datasets.core import lazy_imports_lib
+from tensorflow_datasets.core import naming
 from tensorflow_datasets.core import splits as splits_lib
 from tensorflow_datasets.core import utils
 from tensorflow_datasets.core.features import top_level_feature
 from tensorflow_datasets.core.proto import dataset_info_pb2
-from tensorflow_datasets.core.proto import json_format
 from tensorflow_datasets.core.utils import gcs_utils
 
-from tensorflow_metadata.proto.v0 import schema_pb2
-from tensorflow_metadata.proto.v0 import statistics_pb2
+from google.protobuf import json_format
+
 
 # Name of the file to output the DatasetInfo protobuf object.
 DATASET_INFO_FILENAME = "dataset_info.json"
@@ -430,7 +427,7 @@ class DatasetInfo(object):
                  "from GCS: %s", self.full_name)
     for fname in data_files:
       out_fname = os.path.join(tmp_dir, os.path.basename(fname))
-      gcs_utils.download_gcs_file(fname, out_fname)
+      tf.io.gfile.copy(gcs_utils.gcs_path(fname), out_fname)
     self.read_from_directory(tmp_dir)
 
   def __repr__(self):
@@ -459,157 +456,54 @@ def _indent(content):
   lines = content.split("\n")
   return "\n".join([lines[0]] + ["    " + l for l in lines[1:]])
 
-#
-#
-# This part is quite a bit messy and can be easily simplified with TFDV
-# libraries, we can cut down the complexity by implementing cases on a need to
-# do basis.
-#
-# My understanding of possible TF's types and shapes and kinds
-# (ex: SparseTensor) is limited, please shout hard and guide on implementation.
-#
-#
 
-_FEATURE_TYPE_MAP = {
-    tf.float16: schema_pb2.FLOAT,
-    tf.float32: schema_pb2.FLOAT,
-    tf.float64: schema_pb2.FLOAT,
-    tf.int8: schema_pb2.INT,
-    tf.int16: schema_pb2.INT,
-    tf.int32: schema_pb2.INT,
-    tf.int64: schema_pb2.INT,
-    tf.uint8: schema_pb2.INT,
-    tf.uint16: schema_pb2.INT,
-    tf.uint32: schema_pb2.INT,
-    tf.uint64: schema_pb2.INT,
-}
-
-_SCHEMA_TYPE_MAP = {
-    schema_pb2.INT: statistics_pb2.FeatureNameStatistics.INT,
-    schema_pb2.FLOAT: statistics_pb2.FeatureNameStatistics.FLOAT,
-    schema_pb2.BYTES: statistics_pb2.FeatureNameStatistics.BYTES,
-    schema_pb2.STRUCT: statistics_pb2.FeatureNameStatistics.STRUCT,
-}
+def _populate_shape(shape_or_dict, prefix, schema_features):
+  """Populates shape in the schema."""
+  if isinstance(shape_or_dict, (tuple, list)):
+    feature_name = "/".join(prefix)
+    if shape_or_dict and feature_name in schema_features:
+      schema_feature = schema_features[feature_name]
+      schema_feature.ClearField("shape")
+      for dim in shape_or_dict:
+        # We denote `None`s as -1 in the shape proto.
+        schema_feature.shape.dim.add().size = -1 if dim is None else dim
+    return
+  for name, val in shape_or_dict.items():
+    prefix.append(name)
+    _populate_shape(val, prefix, schema_features)
+    prefix.pop()
 
 
-# TODO(afrozm): What follows below can *VERY EASILY* be done by TFDV - rewrite
-# this section once they are python 3 ready.
 def get_dataset_feature_statistics(builder, split):
   """Calculate statistics for the specified split."""
-  statistics = statistics_pb2.DatasetFeatureStatistics()
+  tfdv = lazy_imports_lib.lazy_imports.tensorflow_data_validation
+  # TODO(epot): Avoid hardcoding file format.
+  filetype_suffix = "tfrecord"
+  if filetype_suffix not in ["tfrecord", "csv"]:
+    raise ValueError(
+        "Cannot generate statistics for filetype {}".format(filetype_suffix))
+  filepattern = naming.filepattern_for_dataset_split(
+      builder.name, split, builder.data_dir, filetype_suffix)
+  # Avoid generating a large number of buckets in rank histogram
+  # (default is 1000).
+  stats_options = tfdv.StatsOptions(num_top_values=10,
+                                    num_rank_histogram_buckets=10)
+  if filetype_suffix == "csv":
+    statistics = tfdv.generate_statistics_from_csv(
+        filepattern, stats_options=stats_options)
+  else:
+    statistics = tfdv.generate_statistics_from_tfrecord(
+        filepattern, stats_options=stats_options)
+  schema = tfdv.infer_schema(statistics)
+  schema_features = {feature.name: feature for feature in schema.feature}
+  # Override shape in the schema.
+  for feature_name, feature in builder.info.features.items():
+    _populate_shape(feature.shape, [feature_name], schema_features)
 
-  # Make this to the best of our abilities.
-  schema = schema_pb2.Schema()
-
-  dataset = builder.as_dataset(split=split)
-
-  # Just computing the number of examples for now.
-  statistics.num_examples = 0
-
-  # Feature dictionaries.
-  feature_to_num_examples = collections.defaultdict(int)
-  feature_to_min = {}
-  feature_to_max = {}
-
-  np_dataset = dataset_utils.as_numpy(dataset)
-  for example in utils.tqdm(np_dataset, unit=" examples", leave=False):
-    statistics.num_examples += 1
-
-    assert isinstance(example, dict)
-
-    feature_names = sorted(example.keys())
-    for feature_name in feature_names:
-
-      # Update the number of examples this feature appears in.
-      feature_to_num_examples[feature_name] += 1
-
-      feature_np = example[feature_name]
-
-      # For compatibility in graph and eager mode, we can get PODs here and
-      # everything may not be neatly wrapped up in numpy's ndarray.
-
-      feature_dtype = type(feature_np)
-
-      if isinstance(feature_np, np.ndarray):
-        # If we have an empty array, then don't proceed further with computing
-        # statistics on it.
-        if feature_np.size == 0:
-          continue
-
-        feature_dtype = feature_np.dtype.type
-
-      feature_min, feature_max = None, None
-      is_numeric = (np.issubdtype(feature_dtype, np.number) or
-                    feature_dtype == np.bool_)
-      if is_numeric:
-        feature_min = np.min(feature_np)
-        feature_max = np.max(feature_np)
-
-      # TODO(afrozm): What if shapes don't match? Populate ValueCount? Add
-      # logic for that.
-
-      # Set or update the min, max.
-      if is_numeric:
-        if ((feature_name not in feature_to_min) or
-            (feature_to_min[feature_name] > feature_min)):
-          feature_to_min[feature_name] = feature_min
-
-        if ((feature_name not in feature_to_max) or
-            (feature_to_max[feature_name] < feature_max)):
-          feature_to_max[feature_name] = feature_max
-
-  # Start here, we've processed all examples.
-
-  output_shapes_dict = tf.compat.v1.data.get_output_shapes(dataset)
-  output_types_dict = tf.compat.v1.data.get_output_types(dataset)
-
-  for feature_name in sorted(feature_to_num_examples.keys()):
-    # Try to fill in the schema.
-    feature = schema.feature.add()
-    feature.name = feature_name
-
-    # TODO(afrozm): Make this work with nested structures, currently the Schema
-    # proto has no support for it.
-    maybe_feature_shape = output_shapes_dict[feature_name]
-    if not isinstance(maybe_feature_shape, tf.TensorShape):
-      logging.error(
-          "Statistics generation doesn't work for nested structures yet")
-      continue
-
-    for dim in maybe_feature_shape.as_list():
-      # We denote `None`s as -1 in the shape proto.
-      feature.shape.dim.add().size = dim if dim else -1
-    feature_type = output_types_dict[feature_name]
-    feature.type = _FEATURE_TYPE_MAP.get(feature_type, schema_pb2.BYTES)
-
-    common_statistics = statistics_pb2.CommonStatistics()
-    common_statistics.num_non_missing = feature_to_num_examples[feature_name]
-    common_statistics.num_missing = (
-        statistics.num_examples - common_statistics.num_non_missing)
-
-    feature_name_statistics = statistics.features.add()
-    feature_name_statistics.name = feature_name
-
-    # TODO(afrozm): This can be skipped, since type information was added to
-    # the Schema.
-    feature_name_statistics.type = _SCHEMA_TYPE_MAP.get(
-        feature.type, statistics_pb2.FeatureNameStatistics.BYTES)
-
-    if feature.type == schema_pb2.INT or feature.type == schema_pb2.FLOAT:
-      numeric_statistics = statistics_pb2.NumericStatistics()
-      # Uses `.get` as Sequence(int) containing only empty array won't contains
-      # any value.
-      numeric_statistics.min = feature_to_min.get(feature_name, 0)
-      numeric_statistics.max = feature_to_max.get(feature_name, 0)
-      numeric_statistics.common_stats.CopyFrom(common_statistics)
-      feature_name_statistics.num_stats.CopyFrom(numeric_statistics)
-    else:
-      # Let's shove it into BytesStatistics for now.
-      bytes_statistics = statistics_pb2.BytesStatistics()
-      bytes_statistics.common_stats.CopyFrom(common_statistics)
-      feature_name_statistics.bytes_stats.CopyFrom(bytes_statistics)
-
-  return statistics, schema
+  # Remove legacy field.
+  if getattr(schema, "generate_legacy_feature_spec", None) is not None:
+    schema.ClearField("generate_legacy_feature_spec")
+  return statistics.datasets[0], schema
 
 
 def read_from_json(json_filename):
