@@ -130,6 +130,11 @@ class LazyImporter(object):
     _try_import("skimage.external.tifffile")
     return _try_import("skimage")
 
+  @utils.classproperty
+  @classmethod
+  def tensorflow_data_validation(cls):
+    return _try_import("tensorflow_data_validation")
+
   @utils.classproperty
   @classmethod
   def tensorflow_io(cls):
