@@ -15,15 +15,7 @@
 
 # Lint as: python3
 """Public API of the proto package."""
-# pylint: disable=g-import-not-at-top,g-importing-member
 
+from tensorflow_datasets.core.proto import dataset_info_generated_pb2 as dataset_info_pb2  # pylint: disable=line-too-long
 
-def _get():
-  from tensorflow_datasets.core.proto import dataset_info_generated_pb2 as dataset_info_pb2_
-  from tensorflow_datasets.core.proto.dataset_info_generated_pb2 import SplitInfo as SplitInfo_
-  from google.protobuf import json_format as json_format_
-  return dataset_info_pb2_, SplitInfo_, json_format_
-
-
-dataset_info_pb2, SplitInfo, json_format = _get()  # pylint: disable=invalid-name
-del _get
+SplitInfo = dataset_info_pb2.SplitInfo
