@@ -48,7 +48,9 @@ from tensorflow_datasets.image_classification.imagenet import Imagenet2012
 from tensorflow_datasets.image_classification.imagenet2012_corrupted import Imagenet2012Corrupted
 from tensorflow_datasets.image_classification.imagenet2012_real import Imagenet2012Real
 from tensorflow_datasets.image_classification.imagenet2012_subset import Imagenet2012Subset
+from tensorflow_datasets.image_classification.imagenet_a import ImagenetA
 from tensorflow_datasets.image_classification.imagenet_resized import ImagenetResized
+from tensorflow_datasets.image_classification.imagenet_v2 import ImagenetV2
 from tensorflow_datasets.image_classification.imagenette import Imagenette
 from tensorflow_datasets.image_classification.imagewang import Imagewang
 from tensorflow_datasets.image_classification.inaturalist import INaturalist2017
