@@ -25,15 +25,20 @@ from tensorflow_datasets.object_detection import waymo_open_dataset
 
 
 class WaymoOpenDatasetTest(testing.DatasetBuilderTestCase):
+  """Waymo Open Dataset tests."""
+
   DATASET_CLASS = waymo_open_dataset.WaymoOpenDataset
+  BUILDER_CONFIG_NAMES_TO_TEST = ["v1.0"]
   SPLITS = {
       "train": 1,  # Number of fake train example
-      "validation": 1,  # Number of fake test example
+      "validation": 1,  # Number of fake validation example
   }
 
   def setUp(self):
+    """Set up Waymo Open Dataset tests."""
     super(WaymoOpenDatasetTest, self).setUp()
-    self.builder._CLOUD_BUCKET = self.example_dir
+    for config in waymo_open_dataset.WaymoOpenDataset.BUILDER_CONFIGS:
+      config.cloud_bucket = self.example_dir
 
 
 if __name__ == "__main__":
