@@ -26,6 +26,8 @@ from tensorflow_datasets.core import decode
 from tensorflow_datasets.core import features
 from tensorflow_datasets.core import units
 from tensorflow_datasets.core import visualization
+from tensorflow_datasets.core.custom_dataset import ImageFolder
+from tensorflow_datasets.core.custom_dataset import TranslateFolder
 from tensorflow_datasets.core.dataset_utils import as_numpy
 from tensorflow_datasets.core.download import GenerateMode
 from tensorflow_datasets.core.registered import builder
@@ -37,6 +39,7 @@ from tensorflow_datasets.core.utils.gcs_utils import is_dataset_on_gcs
 from tensorflow_datasets.core.utils.read_config import ReadConfig
 from tensorflow_datasets.core.utils.tqdm_utils import disable_progress_bar
 from tensorflow_datasets.core.visualization import show_examples
+from tensorflow_datasets.core.visualization import show_statistics
 from tensorflow_datasets.version import __version__
 
 with core.registered.skip_registration():
@@ -46,23 +49,26 @@ with core.registered.skip_registration():
 
 
 __all__ = [
-    "core",
     "as_numpy",
-    "decode",
-    "download",
-    "features",
-    "units",
-    "GenerateMode",
+    "core",
     "builder",
     "builder_cls",
+    "decode",
+    "disable_progress_bar",
+    "download",
+    "features",
+    "GenerateMode",
+    "ImageFolder",
+    "is_dataset_on_gcs",
     "list_builders",
     "load",
     "ReadConfig",
     "Split",
-    "testing",
-    "disable_progress_bar",
-    "is_dataset_on_gcs",
     "show_examples",
+    "show_statistics",
+    "testing",
+    "TranslateFolder",
+    "units",
     "visualization",
     "__version__",
 ]
