@@ -149,7 +149,7 @@ class Ucf101(tfds.core.GeneratorBasedBuilder):
         builder=self,
         description='A 101-label video classification dataset.',
         features=features,
-        homepage='https://www.crcv.ucf.edu/data/UCF101.php',
+        homepage='https://www.crcv.ucf.edu/data-sets/ucf101/',
         citation=_CITATION,
     )
 
